
|build| |pypi| |devdocs| |pyup|


pypoc
=====

Python package for analysis of molecular dynamics simulations of lipids membranes.
See docs_.

Installation
============

You can install ``pypoc`` from the `Python package index`_ using ``pip``:

``pip install pypoc``

The development version can be installed directly from ``github`` via ``pip``:

``pip install git+https://github.com/alejogiley/pypoc.git``

Usage
=====

untested release

Authors
=======

Alejandro Gil-Ley <alejogiley@gmail.com>

License
=======

``pypoc`` is free software and is licensed under the MIT license.

Credits
=======

This package was created with cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. Footnotes

.. _docs: http://pypoc.readthedocs.org/en/latest/
.. _`Python package index`: https://pypi.python.org/pypi/pypoc
.. _cookiecutter: https://github.com/audreyr/cookiecutter
.. _audreyr/cookiecutter-pypackage: https://github.com/audreyr/cookiecutter-pypackage

.. |devdocs| image:: https://readthedocs.org/projects/pypoc/badge/?badge=latest
   :alt: Documentation (development version)
   :target: https://www.mdanalysis.org/mdanalysis/

.. |build| image:: https://img.shields.io/travis/alejogiley/pypoc.svg
   :alt: Build Status
   :target: https://travis-ci.org/alejogiley/pypoc

.. |pypi| image:: https://img.shields.io/pypi/v/pypoc.svg
   :alt: Build Status
   :target: https://pypi.org/pypi/pypoc

.. |pyup| image:: https://pyup.io/repos/github/alejogiley/pypoc/shield.svg
   :alt: My PyUP
   :target: https://pyup.io/repos/github/alejogiley/pypoc/
